Lemberg.AI Software Development Kit (SDK) for Python
====================================================

[![Project license](https://img.shields.io/badge/license-Public%20Domain-blue.svg)](https://unlicense.org)
[![PyPI package](https://img.shields.io/pypi/v/lemberg_ai.svg)](https://pypi.org/project/lemberg_ai/)

Installation
------------

    $ pip install lemberg_ai
